@@ -99,20 +99,45 @@ async function fetchNativeCode(url, version, path) {
 }
 
 function buildLocally() {
+    const platform = os.platform();
+    let arch = os.arch();
+
+    // Allow cross-compile (so OSX can do arm64 or x64 builds) via:
+    // --target-arch ARCH
+    if (process.argv.includes('--target-arch')) {
+        arch = process.argv[process.argv.indexOf('--target-arch') + 1];
+    }
+
+    // options for cmake.BuildSystem
     let options = {
-        CMAKE_EXPORT_COMPILE_COMMANDS: true,
-        CMAKE_JS_PLATFORM: os.platform,
-        CMAKE_JS_ARCH: os.arch,
-        BUILD_TESTING: 'OFF',
-        CMAKE_INSTALL_PREFIX: 'crt/install',
-        CMAKE_PREFIX_PATH: 'crt/install',
+        target: "install",
+        debug: process.argv.includes('--debug'),
+        arch: arch,
+        out: path.join('build', `${platform}-${arch}`),
+        cMakeOptions: {
+            CMAKE_EXPORT_COMPILE_COMMANDS: true,
+            CMAKE_JS_PLATFORM: platform,
+            BUILD_TESTING: 'OFF',
+            CMAKE_INSTALL_PREFIX: 'crt/install',
+            CMAKE_PREFIX_PATH: 'crt/install',
+        }
+    }
+
+    // We need to pass some extra flags to pull off cross-compiling
+    // because cmake-js doesn't set everything we need.
+    //
+    // See the docs on `arch`: https://github.com/cmake-js/cmake-js/blob/v6.1.0/README.md?#runtimes
+    // > Notice: on non-Windows systems the C++ toolset's architecture's gonna be used despite this setting.
+    if (platform === 'darwin') {
+        // What Node calls "x64", Apple calls "x86_64". They both agree on the term "arm64" though.
+        options.cMakeOptions.CMAKE_OSX_ARCHITECTURES = (arch === 'x64') ? 'x86_64' : arch;
     }
 
     // Convert any -D arguments to this script to cmake -D arguments
     for (const arg of process.argv) {
         if (arg.startsWith('-D')) {
             const option = arg.substring(2).split('=')
-            options[option[0]] = option[1]
+            options.cMakeOptions[option[0]] = option[1]
         }
     }
 
@@ -120,11 +145,7 @@ function buildLocally() {
     process.env.CMAKE_BUILD_PARALLEL_LEVEL = `${Math.max(os.cpus().length, 1)}`;
 
     // Run the build
-    var buildSystem = new cmake.BuildSystem({
-        target: "install",
-        debug: process.argv.includes('--debug'),
-        cMakeOptions: options,
-    });
+    var buildSystem = new cmake.BuildSystem(options);
     return buildSystem.build();
 }
 
