@@ -678,6 +678,8 @@ static bool s_module_initialized = false;
     CREATE_AND_REGISTER_FN(io_socket_options_new)
     CREATE_AND_REGISTER_FN(io_input_stream_new)
     CREATE_AND_REGISTER_FN(io_input_stream_append)
+    CREATE_AND_REGISTER_FN(io_pkcs11_lib_new)
+    CREATE_AND_REGISTER_FN(io_pkcs11_lib_close)
 
     /* MQTT Client */
     CREATE_AND_REGISTER_FN(mqtt_client_new)
